{
  inputs = {
    nixpkgs.url = "flake:nixpkgs/nixos-23.05";
    nixpkgs-unstable.url = "flake:nixpkgs/nixos-unstable";
    utils.url = "github:gytis-ivaskevicius/flake-utils-plus/v1.3.1";
    simple-nixos-mailserver = {
      url = "gitlab:simple-nixos-mailserver/nixos-mailserver/nixos-23.05";
      inputs = {
        nixpkgs.follows = "nixpkgs-unstable";
        nixpkgs-23_05.follows = "nixpkgs";
      };
    };
    dogetipbot-telegram = {
      url = "gitlab:nyanloutre/dogetipbot-telegram/master";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    ipmihddtemp = {
      url = "gitlab:nyanloutre/ipmihddtemp/master";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  outputs = inputs@{ self, utils, nixpkgs, nixpkgs-unstable, simple-nixos-mailserver, dogetipbot-telegram, ipmihddtemp }: utils.lib.mkFlake {

    inherit self inputs;

    supportedSystems = [ "x86_64-linux" ];

    # Patch example

    # channels.nixpkgs-unstable.patches = [
    #   (nixpkgs-unstable.legacyPackages."x86_64-linux".fetchpatch {
    #     name = "electron-cash.patch";
    #     url = "https://github.com/NixOS/nixpkgs/pull/160607.patch";
    #     sha256 = nixpkgs.lib.fakeHash;
    #   })
    # ];

    channels.nixpkgs-unstable.patches = [
      (nixpkgs-unstable.legacyPackages."x86_64-linux".fetchpatch {
        name = "249059.patch";
        url = "https://github.com/NixOS/nixpkgs/commit/7957b4cfd79a6b7871d31e5acd84f75fc3e7ca59.patch";
        sha256 = "sha256-Ue9qzggPooVSgyzJiPhQm7+79L5d7IYX3fAXmYjTTiE=";
      })
    ];

    hostDefaults.modules = [
      nixpkgs.nixosModules.notDetected
      {
        nix.generateRegistryFromInputs = true;
        nix.linkInputs = true;
        nix.generateNixPathFromInputs = true;
      }
    ];

    hosts.loutreos.modules = [
      simple-nixos-mailserver.nixosModule
      dogetipbot-telegram.nixosModule
      ipmihddtemp.nixosModule
      ./systems/LoutreOS/configuration.nix
    ];

    hosts.paul-fixe = {
      channelName = "nixpkgs-unstable";
      modules = [
        ./systems/PC-Fixe/configuration.nix
      ];
    };
  };
}

